# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedPercentageResponse(Model):
    """FixedPercentageResponse.

    :param destination_account:
    :type destination_account: ~energycap.sdk.models.AccountChildWithType
    :param destination_meter:
    :type destination_meter: ~energycap.sdk.models.MeterChild
    :param destination_place:
    :type destination_place: ~energycap.sdk.models.PlaceChildWithFloorArea
    :param split_percentage: Fixed percentage to apply in bill split for this
     account and meter
    :type split_percentage: float
    """

    _attribute_map = {
        'destination_account': {'key': 'destinationAccount', 'type': 'AccountChildWithType'},
        'destination_meter': {'key': 'destinationMeter', 'type': 'MeterChild'},
        'destination_place': {'key': 'destinationPlace', 'type': 'PlaceChildWithFloorArea'},
        'split_percentage': {'key': 'splitPercentage', 'type': 'float'},
    }

    def __init__(self, destination_account=None, destination_meter=None, destination_place=None, split_percentage=None):
        super(FixedPercentageResponse, self).__init__()
        self.destination_account = destination_account
        self.destination_meter = destination_meter
        self.destination_place = destination_place
        self.split_percentage = split_percentage
